@@ -16,8 +16,9 @@ __all__ = [
 from functools import partial
 from typing import TYPE_CHECKING, Any
 
+from coola.recursive import recursive_apply
+
 from batcharray import array as ba
-from batcharray.recursive import recursive_apply
 
 if TYPE_CHECKING:
     from collections.abc import Hashable, Sequence
@@ -44,23 +45,21 @@ def chunk_along_batch(
     Returns:
         The data chuncks.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import chunk_along_batch
+        >>> data = {
+        ...     "a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]),
+        ...     "b": np.array([4, 3, 2, 1, 0]),
+        ... }
+        >>> outputs = chunk_along_batch(data, chunks=3)
+        >>> outputs
+        [{'a': array([[0, 1], [2, 3]]), 'b': array([4, 3])},
+         {'a': array([[4, 5], [6, 7]]), 'b': array([2, 1])},
+         {'a': array([[8, 9]]), 'b': array([0])}]
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import chunk_along_batch
-    >>> data = {
-    ...     "a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]),
-    ...     "b": np.array([4, 3, 2, 1, 0]),
-    ... }
-    >>> outputs = chunk_along_batch(data, chunks=3)
-    >>> outputs
-    [{'a': array([[0, 1], [2, 3]]), 'b': array([4, 3])},
-     {'a': array([[4, 5], [6, 7]]), 'b': array([2, 1])},
-     {'a': array([[8, 9]]), 'b': array([0])}]
-
-    ```
+        ```
     """
     keys = data.keys()
     return [
@@ -86,22 +85,23 @@ def chunk_along_seq(
         chunks: Number of chunks to return.
 
     Returns:
-        The data chuncks.
+        The data chunks.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import chunk_along_seq
+        >>> data = {
+        ...     "a": np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]),
+        ...     "b": np.array([[4, 3, 2, 1, 0]]),
+        ... }
+        >>> outputs = chunk_along_seq(data, chunks=3)
+        >>> outputs
+        [{'a': array([[0, 1], [5, 6]]), 'b': array([[4, 3]])},
+         {'a': array([[2, 3], [7, 8]]), 'b': array([[2, 1]])},
+         {'a': array([[4], [9]]), 'b': array([[0]])}]
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import chunk_along_seq
-    >>> data = {'a': np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]), 'b': np.array([[4, 3, 2, 1, 0]])}
-    >>> outputs = chunk_along_seq(data, chunks=3)
-    >>> outputs
-    [{'a': array([[0, 1], [5, 6]]), 'b': array([[4, 3]])},
-     {'a': array([[2, 3], [7, 8]]), 'b': array([[2, 1]])},
-     {'a': array([[4], [9]]), 'b': array([[0]])}]
-
-    ```
+        ```
     """
     keys = data.keys()
     return [
@@ -128,18 +128,19 @@ def select_along_batch(data: Any, index: int) -> Any:
     Returns:
         The sliced arrays along the batch axis.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import select_along_batch
+        >>> data = {
+        ...     "a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]),
+        ...     "b": np.array([4, 3, 2, 1, 0]),
+        ... }
+        >>> out = select_along_batch(data, index=2)
+        >>> out
+        {'a': array([4, 5]), 'b': np.int64(2)}
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import select_along_batch
-    >>> data = {"a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]), "b": np.array([4, 3, 2, 1, 0])}
-    >>> out = select_along_batch(data, index=2)
-    >>> out
-    {'a': array([4, 5]), 'b': np.int64(2)}
-
-    ```
+        ```
     """
     return recursive_apply(data, partial(ba.select_along_batch, index=index))
 
@@ -162,18 +163,19 @@ def select_along_seq(data: Any, index: int) -> Any:
     Returns:
         The sliced arrays along the sequence axis.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import select_along_seq
+        >>> data = {
+        ...     "a": np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]),
+        ...     "b": np.array([[4, 3, 2, 1, 0]]),
+        ... }
+        >>> out = select_along_seq(data, index=2)
+        >>> out
+        {'a': array([2, 7]), 'b': array([2])}
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import select_along_seq
-    >>> data = {'a': np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]), 'b': np.array([[4, 3, 2, 1, 0]])}
-    >>> out = select_along_seq(data, index=2)
-    >>> out
-    {'a': array([2, 7]), 'b': array([2])}
-
-    ```
+        ```
     """
     return recursive_apply(data, partial(ba.select_along_seq, index=index))
 
@@ -194,32 +196,33 @@ def slice_along_batch(data: Any, start: int = 0, stop: int | None = None, step:
         step: The increment between each index for slicing.
 
     Returns:
-        The sliced array along the batch axis.
+        The sliced arrays along the batch axis.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import slice_along_batch
+        >>> data = {
+        ...     "a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]),
+        ...     "b": np.array([4, 3, 2, 1, 0]),
+        ... }
+        >>> out = slice_along_batch(data, start=2)
+        >>> out
+        {'a': array([[4, 5], [6, 7], [8, 9]]), 'b': array([2, 1, 0])}
+        >>> out = slice_along_batch(data, stop=3)
+        >>> out
+        {'a': array([[0, 1], [2, 3], [4, 5]]), 'b': array([4, 3, 2])}
+        >>> out = slice_along_batch(data, step=2)
+        >>> out
+        {'a': array([[0, 1], [4, 5], [8, 9]]), 'b': array([4, 2, 0])}
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import slice_along_batch
-    >>> data = {"a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]), "b": np.array([4, 3, 2, 1, 0])}
-    >>> out = slice_along_batch(data, start=2)
-    >>> out
-    {'a': array([[4, 5], [6, 7], [8, 9]]), 'b': array([2, 1, 0])}
-    >>> out = slice_along_batch(data, stop=3)
-    >>> out
-    {'a': array([[0, 1], [2, 3], [4, 5]]), 'b': array([4, 3, 2])}
-    >>> out = slice_along_batch(data, step=2)
-    >>> out
-    {'a': array([[0, 1], [4, 5], [8, 9]]), 'b': array([4, 2, 0])}
-
-    ```
+        ```
     """
     return recursive_apply(data, partial(ba.slice_along_batch, start=start, stop=stop, step=step))
 
 
 def slice_along_seq(data: Any, start: int = 0, stop: int | None = None, step: int = 1) -> Any:
-    r"""Slice all the arrays along the batch axis.
+    r"""Slice all the arrays along the sequence axis.
 
     Note:
         This function assumes the sequence axis is the second
@@ -234,26 +237,27 @@ def slice_along_seq(data: Any, start: int = 0, stop: int | None = None, step: in
         step: The increment between each index for slicing.
 
     Returns:
-        The sliced array along the batch axis.
+        The sliced arrays along the sequence axis.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import slice_along_seq
+        >>> data = {
+        ...     "a": np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]),
+        ...     "b": np.array([[4, 3, 2, 1, 0]]),
+        ... }
+        >>> out = slice_along_seq(data, start=2)
+        >>> out
+        {'a': array([[2, 3, 4], [7, 8, 9]]), 'b': array([[2, 1, 0]])}
+        >>> out = slice_along_seq(data, stop=3)
+        >>> out
+        {'a': array([[0, 1, 2], [5, 6, 7]]), 'b': array([[4, 3, 2]])}
+        >>> out = slice_along_seq(data, step=2)
+        >>> out
+        {'a': array([[0, 2, 4], [5, 7, 9]]), 'b': array([[4, 2, 0]])}
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import slice_along_seq
-    >>> data = {'a': np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]), 'b': np.array([[4, 3, 2, 1, 0]])}
-    >>> out = slice_along_seq(data, start=2)
-    >>> out
-    {'a': array([[2, 3, 4], [7, 8, 9]]), 'b': array([[2, 1, 0]])}
-    >>> out = slice_along_seq(data, stop=3)
-    >>> out
-    {'a': array([[0, 1, 2], [5, 6, 7]]), 'b': array([[4, 3, 2]])}
-    >>> out = slice_along_seq(data, step=2)
-    >>> out
-    {'a': array([[0, 2, 4], [5, 7, 9]]), 'b': array([[4, 2, 0]])}
-
-    ```
+        ```
     """
     return recursive_apply(data, partial(ba.slice_along_seq, start=start, stop=stop, step=step))
 
@@ -276,22 +280,23 @@ def split_along_batch(
             sizes for each chunk
 
     Returns:
-        The data chuncks.
+        The data chunks.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import split_along_batch
+        >>> data = {
+        ...     "a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]),
+        ...     "b": np.array([4, 3, 2, 1, 0]),
+        ... }
+        >>> outputs = split_along_batch(data, split_size_or_sections=2)
+        >>> outputs
+        [{'a': array([[0, 1], [2, 3]]), 'b': array([4, 3])},
+         {'a': array([[4, 5], [6, 7]]), 'b': array([2, 1])},
+         {'a': array([[8, 9]]), 'b': array([0])}]
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import split_along_batch
-    >>> data = {"a": np.array([[0, 1], [2, 3], [4, 5], [6, 7], [8, 9]]), "b": np.array([4, 3, 2, 1, 0])}
-    >>> outputs = split_along_batch(data, split_size_or_sections=2)
-    >>> outputs
-    [{'a': array([[0, 1], [2, 3]]), 'b': array([4, 3])},
-     {'a': array([[4, 5], [6, 7]]), 'b': array([2, 1])},
-     {'a': array([[8, 9]]), 'b': array([0])}]
-
-    ```
+        ```
     """
     keys = data.keys()
     return [
@@ -320,22 +325,23 @@ def split_along_seq(
             sizes for each chunk
 
     Returns:
-        The data chuncks.
+        The data chunks.
 
-    Example usage:
+    Example:
+        ```pycon
+        >>> import numpy as np
+        >>> from batcharray.nested import split_along_seq
+        >>> data = {
+        ...     "a": np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]),
+        ...     "b": np.array([[4, 3, 2, 1, 0]]),
+        ... }
+        >>> outputs = split_along_seq(data, split_size_or_sections=2)
+        >>> outputs
+        [{'a': array([[0, 1], [5, 6]]), 'b': array([[4, 3]])},
+         {'a': array([[2, 3], [7, 8]]), 'b': array([[2, 1]])},
+         {'a': array([[4], [9]]), 'b': array([[0]])}]
 
-    ```pycon
-
-    >>> import numpy as np
-    >>> from batcharray.nested import split_along_seq
-    >>> data = {"a": np.array([[0, 1, 2, 3, 4], [5, 6, 7, 8, 9]]), "b": np.array([[4, 3, 2, 1, 0]])}
-    >>> outputs = split_along_seq(data, split_size_or_sections=2)
-    >>> outputs
-    [{'a': array([[0, 1], [5, 6]]), 'b': array([[4, 3]])},
-     {'a': array([[2, 3], [7, 8]]), 'b': array([[2, 1]])},
-     {'a': array([[4], [9]]), 'b': array([[0]])}]
-
-    ```
+        ```
     """
     keys = data.keys()
     return [
